@@ -91,9 +91,7 @@ class HLObject(object):
     @property
     def file(self):
         """Return a File instance associated with this object"""
-        register_thread()
-        fid = h5i.get_file_id(self.id)
-        return File(None, bind=fid)
+        return self._file
 
     @property
     def _lapl(self):
@@ -123,7 +121,7 @@ class HLObject(object):
         register_thread()
         return h5i.get_name(self.id)
 
-    @_extras.cproperty('_attrs')
+    @property
     def attrs(self):
         """Provides access to HDF5 attributes. See AttributeManager."""
         return AttributeManager(self)
@@ -138,7 +136,7 @@ class HLObject(object):
             raise ValueError("Parent of an anonymous object is undefined")
         return self.file[pp.dirname(self.name)]
 
-    @_extras.cproperty('_ref')
+    @property
     def ref(self):
         """ An (opaque) HDF5 reference to this object """
         register_thread()
@@ -146,8 +144,11 @@ class HLObject(object):
 
     def __init__(self, oid):
         """ Setup this object, given its low-level identifier """
-        #self._file = self._get_file(oid)
+        register_thread()
         self._id = oid
+        if not isinstance(self, File):
+            fid = h5i.get_file_id(oid)
+            self._file = File(None, bind=fid)
 
     def __nonzero__(self):
         register_thread()
@@ -262,7 +263,10 @@ class Group(HLObject, _DictCompat):
             if _rawid is not None:
                 id = _rawid
             elif create:
-                id = h5g.create(parent_object.id, name)
+                if config.API_18:
+                    id = h5g.create(parent_object.id, name, lcpl=self._lcpl)
+                else:
+                    id = h5g.create(parent_object.id, name)
             else:
                 id = h5g.open(parent_object.id, name)
             HLObject.__init__(self, id)
@@ -919,7 +923,7 @@ class Dataset(HLObject):
 
     shape = property(_g_shape, _s_shape)
 
-    @_extras.cproperty('_dtype')
+    @property
     def dtype(self):
         """Numpy dtype representing the datatype"""
         register_thread()
@@ -934,11 +938,11 @@ class Dataset(HLObject):
             #    return numpy.asscalar(arr)
             return arr
 
-    @_extras.cproperty('__dcpl')
+    @property
     def _dcpl(self):
         return self.id.get_create_plist()
 
-    @_extras.cproperty('__filters')
+    @property
     def _filters(self):
         return filters.get_filters(self._dcpl)
 
@@ -1088,7 +1092,10 @@ class Dataset(HLObject):
                 space_id = h5s.create_simple(shape, maxshape)
                 type_id = h5t.py_create(dtype, logical=True)
 
-                id = h5d.create(group.id, name, type_id, space_id, plist)
+                if config.API_18:
+                    id = h5d.create(group.id, name, type_id, space_id, dcpl=plist, lcpl=self._lcpl)
+                else:
+                    id = h5d.create(group.id, name, type_id, space_id, dcpl=plist)
                 if data is not None:
                     id.write(h5s.ALL, h5s.ALL, data)
             HLObject.__init__(self, id)
@@ -1209,8 +1216,15 @@ class Dataset(HLObject):
             # discards the array information at the top level.
             mtype = h5t.py_create(new_dtype)
 
+            # HDF5 has a bug where if the memory shape has a different rank
+            # than the dataset, the read is very slow
+            mshape = selection.mshape
+            if len(mshape) < len(self.shape):
+                # pad with ones
+                mshape = (1,)*(len(self.shape)-len(mshape)) + mshape
+
             # Perfom the actual read
-            mspace = h5s.create_simple(selection.mshape)
+            mspace = h5s.create_simple(mshape)
             fspace = selection._id
             self.id.read(mspace, fspace, arr, mtype)
 
@@ -1374,7 +1388,6 @@ class AttributeManager(_DictCompat):
         """ Private constructor.
         """
         self._id = parent.id
-        self._file = parent.file
 
     def __getitem__(self, name):
         """ Read the value of an attribute.
